@@ -1,4 +1,4 @@
-//    Copyright (C) 2009 Dirk Vanden Boer <dirk.vdb@gmail.com>
+//    Copyright (C) 2010 Dirk Vanden Boer <dirk.vdb@gmail.com>
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -37,12 +37,14 @@
 #include <inttypes.h>
 #include <stdexcept>
 
+namespace ffmpegthumbnailer
+{
 
 template <typename T>
 class ImageWriterFactory
 {
 public:
-    static ImageWriter* createImageWriter(ImageType imageType, T output)
+    static ImageWriter* createImageWriter(ThumbnailerImageType imageType, T output)
     {
         switch (imageType)
         {
@@ -64,4 +66,6 @@ public:
     }
 };
 
+}
+
 #endif
