@@ -1,4 +1,4 @@
-//    Copyright (C) 2009 Dirk Vanden Boer <dirk.vdb@gmail.com>
+//    Copyright (C) 2010 Dirk Vanden Boer <dirk.vdb@gmail.com>
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 
 #include "imagewriter.h"
 
+namespace ffmpegthumbnailer
+{
+
 class PngWriter : public ImageWriter
 {
 public:
@@ -42,4 +45,6 @@ private:
 	png_infop 	            m_InfoPtr;
 };
 
+}
+
 #endif
